pub fn is_buffer_read_supported<C>(ctxt: &C) -> boolwhere
C: CapabilitiesSource + ?Sized,Expand description
Returns true if reading from a buffer is supported by the backend.
pub fn is_buffer_read_supported<C>(ctxt: &C) -> boolwhere
C: CapabilitiesSource + ?Sized,Returns true if reading from a buffer is supported by the backend.