pub struct ConditionalRendering<'a> {
pub query: SamplesQueryParam<'a>,
pub wait: bool,
pub per_region: bool,
}Expand description
Condition whether to render or not.
Fields
query: SamplesQueryParam<'a>The query to use.
wait: boolIf true, the GPU will wait until the query result has been obtained. If false, the GPU is free to ignore the query and draw anyway.
per_region: boolIf true, only samples that match those that were written with the query active will be drawn.