pub struct DepthStencilRenderBuffer { /* private fields */ }Expand description
A render buffer is similar to a texture, but is optimized for usage as a draw target.
Contrary to a texture, you can’t sample or modify the content of the DepthStencilRenderBuffer directly.
Implementations
Sourceimpl DepthStencilRenderBuffer
impl DepthStencilRenderBuffer
Sourcepub fn new<F>(
facade: &F,
format: DepthStencilFormat,
width: u32,
height: u32,
) -> Result<DepthStencilRenderBuffer, CreationError>
pub fn new<F>( facade: &F, format: DepthStencilFormat, width: u32, height: u32, ) -> Result<DepthStencilRenderBuffer, CreationError>
Builds a new render buffer.
Sourcepub fn new_multisample<F>(
facade: &F,
format: DepthStencilFormat,
width: u32,
height: u32,
samples: u32,
) -> Result<DepthStencilRenderBuffer, CreationError>
pub fn new_multisample<F>( facade: &F, format: DepthStencilFormat, width: u32, height: u32, samples: u32, ) -> Result<DepthStencilRenderBuffer, CreationError>
Builds a new render buffer with multisampling.
Methods from Deref<Target = RenderBufferAny>
Sourcepub fn get_dimensions(&self) -> (u32, u32)
pub fn get_dimensions(&self) -> (u32, u32)
Returns the dimensions of the render buffer.
Sourcepub fn get_samples(&self) -> Option<u32>
pub fn get_samples(&self) -> Option<u32>
Returns the number of samples of the render buffer, or None if multisampling isn’t
enabled.
Sourcepub fn get_context(&self) -> &Rc<Context>
pub fn get_context(&self) -> &Rc<Context>
Returns the context used to create this renderbuffer.
Sourcepub fn kind(&self) -> TextureKind
pub fn kind(&self) -> TextureKind
Returns the kind of renderbuffer.
Sourcepub fn get_depth_stencil_bits(&self) -> (u16, u16)
pub fn get_depth_stencil_bits(&self) -> (u16, u16)
Determines the number of depth and stencil bits in the format of this render buffer.