pub struct TransformFeedbackVarying {
pub name: String,
pub offset: usize,
pub size: usize,
pub ty: AttributeType,
}Expand description
Describes a varying that is being output with transform feedback.
Fields
name: StringName of the variable.
offset: usizeNumber of bytes between the start of the first element and the start of this one.
size: usizeSize in bytes of this value.
ty: AttributeTypeType of the value.