SyncFence

Struct SyncFence 

pub struct SyncFence { /* private fields */ }
Provides a way to wait for a server-side operation to be finished.

Creating a SyncFence injects an element in the commands queue of the backend. When this element is reached, the fence becomes signaled.

Example

let fence = glium::SyncFence::new(&display).unwrap();
do_something(&display);
fence.wait();   // blocks until the previous operations have finished

Implementations

Source

impl SyncFence

pub fn new<F>(facade: &F) -> Result<SyncFence, SyncNotSupportedError>
where F: Facade + ?Sized,

Builds a new SyncFence that is injected in the server.

pub fn wait(self)

Blocks until the operation has finished on the server.