pub unsafe trait TextureBufferContent: BufferContent {
// Required method
fn get_type() -> TextureBufferContentType;
}Expand description
Trait for data types that can be interpreted by a buffer texture.
Required Methods
Sourcefn get_type() -> TextureBufferContentType
fn get_type() -> TextureBufferContentType
Returns the enumeration corresponding to elements of this data type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.