UncompressedUintFormat

Enum UncompressedUintFormat 

pub enum UncompressedUintFormat {
Show 13 variants U8, U16, U32, U8U8, U16U16, U32U32, U8U8U8, U16U16U16, U32U32U32, U8U8U8U8, U16U16U16U16, U32U32U32U32, U10U10U10U2,
}
List of uncompressed pixel formats that contain unsigned integral data.

Variants



U8



U16



U32



U8U8



U16U16



U32U32



U8U8U8



U16U16U16

May not be supported by renderbuffers.



U32U32U32

May not be supported by renderbuffers.



U8U8U8U8

May not be supported by renderbuffers.



U16U16U16U16



U32U32U32U32



U10U10U10U2

Implementations

Source

impl UncompressedUintFormat

pub fn get_formats_list() -> Vec<UncompressedUintFormat>

Returns a list of all the possible values of this enumeration.

pub fn to_texture_format(self) -> TextureFormat

Turns this format into a more generic TextureFormat.

pub fn is_supported<C>(&self, context: &C) -> bool

Returns true if this format is supported by the backend.

pub fn is_color_renderable<C>(&self, context: &C) -> bool

Returns true if a texture or renderbuffer with this format can be used as a framebuffer attachment.