pub enum ImageUnitAccess {
Read,
Write,
ReadWrite,
}Expand description
States how the shader will access the image unit
Variants
Read
The shader will only read from the image unit
Write
The shader will only write to the image unit
ReadWrite
The shader will perform both reads and writes to the image unit