pub enum LayoutMismatchError {
TypeMismatch {
expected: UniformType,
obtained: UniformType,
},
LayoutMismatch {
expected: BlockLayout,
obtained: BlockLayout,
},
OffsetMismatch {
expected: usize,
obtained: usize,
},
MemberMismatch {
member: String,
err: Box<LayoutMismatchError>,
},
MissingField {
name: String,
},
}Expand description
Error about a block layout mismatch.
Variants
TypeMismatch
There is a mismatch in the type of one element.
LayoutMismatch
The expected layout is totally different from what we have.
Fields

expected: BlockLayoutLayout expected by the shader.

obtained: BlockLayoutLayout of the input.
OffsetMismatch
The type of data is good, but there is a misalignment.
Fields
MemberMismatch
There is a mismatch in a submember of this layout.
This is kind of a hierarchy inside the LayoutMismatchErrors.
MissingField
A field is missing in either the expected of the input data layout.