pub enum MagnifySamplerFilter {
Nearest,
Linear,
}Expand description
The function that the GPU will use when loading the value of a texel.
Variants
Nearest
The nearest texel will be loaded.
Linear
All nearby texels will be loaded and their values will be merged.